"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidContext = exports.isKnownContext = exports.isDefaultContext = void 0;
const constants_1 = require("./constants");
/**
 * Check if the given context name is the default one
 * @param {string} context context name
 *
 * @return {boolean} result
 */
exports.isDefaultContext = (context) => context === constants_1.KnownContext.Default;
/**
 * Check if the given context is in the reserved contexts list
 * @param {string} context context name
 *
 * @returns {boolean} result
 */
exports.isKnownContext = (context) => constants_1.RESERVED_CONTEXT_NAMES.includes(context);
/**
 * Check if the given context is valid by checking branch names and known contexts.
 * @param {string} context context name
 * @param {NetlifyContextSettings} settings site setting
 *
 * @return {boolean} result
 */
exports.isValidContext = (context, settings) => exports.isKnownContext(context) || settings.branches.includes(context);
